@@ -1,4 +1,4 @@
-/* $Id: console.cpp 11832 2008-01-13 13:36:01Z rubidium $ */
+/* $Id: console.cpp 14426 2008-10-01 11:48:57Z rubidium $ */
 
 /** @file console.cpp */
 
@@ -697,7 +697,7 @@ IConsoleAlias *IConsoleAliasGet(const char *name)
 static inline int IConsoleCopyInParams(char *dst, const char *src, uint bufpos)
 {
 	int len = min(ICON_MAX_STREAMSIZE - bufpos, (uint)strlen(src));
-	strncpy(dst, src, len);
+	strecpy(dst, src, dst + len - 1);
 
 	return len;
 }
