@@ -1,4 +1,4 @@
-/* $Id: engine.cpp 12864 2008-04-24 11:48:09Z rubidium $ */
+/* $Id: engine.cpp 14268 2008-09-07 22:04:39Z rubidium $ */
 
 /** @file engine.cpp */
 
@@ -173,6 +173,13 @@ void StartupEngines()
 			e->player_avail = 0;
 		}
 	}
+
+	/* Update the bitmasks for the vehicle lists */
+	Player *p;
+	FOR_ALL_PLAYERS(p) {
+		p->avail_railtypes = GetPlayerRailtypes(p->index);
+		p->avail_roadtypes = GetPlayerRoadtypes(p->index);
+	}
 }
 
 static void AcceptEnginePreview(EngineID eid, PlayerID player)
