@@ -1,4 +1,4 @@
-/* $Id: newgrf_text.cpp 12523 2008-03-31 21:46:15Z rubidium $ */
+/* $Id: newgrf_text.cpp 14267 2008-09-07 21:41:47Z rubidium $ */
 
 /** @file newgrf_text.cpp
  * Implementation of  Action 04 "universal holder" structure and functions.
@@ -238,8 +238,8 @@ char *TranslateTTDPatchCodes(uint32 grfid, const char *str)
 			case 0x80: d += Utf8Encode(d, SCC_NEWGRF_PRINT_DWORD + c - 0x7B); break;
 			case 0x81: {
 				StringID string;
-				string  = *str++;
-				string |= *str++ << 8;
+				string  = ((uint8)*str++);
+				string |= ((uint8)*str++) << 8;
 				d += Utf8Encode(d, SCC_STRING_ID);
 				d += Utf8Encode(d, MapGRFStringID(grfid, string));
 				break;
@@ -270,14 +270,22 @@ char *TranslateTTDPatchCodes(uint32 grfid, const char *str)
 			case 0x9A:
 				switch (*str++) {
 					case 0: /* FALL THROUGH */
-					case 1: d += Utf8Encode(d, SCC_NEWGRF_PRINT_QWORD_CURRENCY); break;
+					case 1:
+						d += Utf8Encode(d, SCC_NEWGRF_PRINT_QWORD_CURRENCY);
+						break;
 					case 3: {
-						uint16 tmp = *str++;
-						tmp |= (*str++) << 8;
-						d += Utf8Encode(d, SCC_NEWGRF_PUSH_WORD); d += Utf8Encode(d, tmp);
+						uint16 tmp  = ((uint8)*str++);
+						tmp        |= ((uint8)*str++) << 8;
+						d += Utf8Encode(d, SCC_NEWGRF_PUSH_WORD);
+						d += Utf8Encode(d, tmp);
 					} break;
-					case 4: d += Utf8Encode(d, SCC_NEWGRF_UNPRINT); d += Utf8Encode(d, *str++); break;
-					default: grfmsg(1, "missing handler for extended format code"); break;
+					case 4:
+						d += Utf8Encode(d, SCC_NEWGRF_UNPRINT);
+						d += Utf8Encode(d, *str++);
+						break;
+					default:
+						grfmsg(1, "missing handler for extended format code");
+						break;
 				}
 				break;
 
@@ -543,8 +551,8 @@ struct TextRefStack {
 		if (this->position >= 2) {
 			this->position -= 2;
 		} else {
-			for (uint i = lengthof(stack) - 3; i >= this->position; i--) {
-				this->stack[this->position + 2] = this->stack[this->position];
+			for (int i = lengthof(stack) - 1; i >= this->position + 2; i--) {
+				this->stack[i] = this->stack[i - 2];
 			}
 		}
 		this->stack[this->position]     = GB(word, 0, 8);
