@@ -1,4 +1,4 @@
-/* $Id: openttd.cpp 13871 2008-07-29 22:37:54Z rubidium $ */
+/* $Id: openttd.cpp 14426 2008-10-01 11:48:57Z rubidium $ */
 
 /** @file openttd.cpp */
 
@@ -425,8 +425,10 @@ int ttd_main(int argc, char *argv[])
 			}
 
 			_switch_mode = SM_NEWGAME;
-			/* Give a random map */
-			generation_seed = InteractiveRandom();
+			/* Give a random map if no seed has been given */
+			if (generation_seed == GENERATE_NEW_SEED) {
+				generation_seed = InteractiveRandom();
+			}
 			break;
 		case 'G': generation_seed = atoi(mgo.opt); break;
 		case 'c': _config_file = strdup(mgo.opt); break;
@@ -1188,8 +1190,8 @@ static void ConvertTownOwner()
 	for (tile = 0; tile != MapSize(); tile++) {
 		switch (GetTileType(tile)) {
 			case MP_ROAD:
-				if (GB(_m[tile].m5, 4, 2) == ROAD_TILE_CROSSING && HasBit(_m[tile].m4, 7)) {
-					_m[tile].m4 = OWNER_TOWN;
+				if (GB(_m[tile].m5, 4, 2) == ROAD_TILE_CROSSING && HasBit(_m[tile].m3, 7)) {
+					_m[tile].m3 = OWNER_TOWN;
 				}
 				/* FALLTHROUGH */
 
@@ -1401,6 +1403,14 @@ bool AfterLoadGame()
 			wp->name = CopyFromOldName(wp->string);
 			wp->string = STR_EMPTY;
 		}
+
+		for (uint i = 0; i < GetSignPoolSize(); i++) {
+			/* invalid signs are determined by si->ower == INVALID_PLAYER now */
+			Sign *si = GetSign(i);
+			if (!si->IsValid() && si->name != NULL) {
+				si->owner = OWNER_NONE;
+			}
+		}
 	}
 
 	/* convert road side to my format. */
@@ -1588,7 +1598,7 @@ bool AfterLoadGame()
 
 				case MP_ROAD:
 					_m[t].m4 |= (_m[t].m2 << 4);
-					if (IsTileOwner(t, OWNER_TOWN)) {
+					if ((GB(_m[t].m5, 4, 2) == ROAD_TILE_CROSSING ? (Owner)_m[t].m3 : GetTileOwner(t)) == OWNER_TOWN) {
 						SetTownIndex(t, CalcClosestTownFromTile(t, (uint)-1)->index);
 					} else {
 						SetTownIndex(t, 0);
@@ -2469,6 +2479,15 @@ bool AfterLoadGame()
 		}
 	}
 
+	/* Just always run this for 0.6. Doesn't hurt to fix the owners a second time. */
+	if (CheckSavegameVersion(103)) {
+		/* signs with invalid owner left from older savegames */
+		Sign *si;
+		FOR_ALL_SIGNS(si) {
+			if (si->owner != OWNER_NONE && !IsValidPlayer(si->owner) && GetPlayer(si->owner)->is_active) si->owner = OWNER_NONE;
+		}
+	}
+
 	return InitializeWindowsAndCaches();
 }
 
