@@ -1,4 +1,4 @@
-/* $Id: players.cpp 13735 2008-07-19 12:23:14Z rubidium $ */
+/* $Id: players.cpp 14347 2008-09-16 20:29:09Z rubidium $ */
 
 /** @file players.cpp
  */
@@ -314,7 +314,7 @@ static void GenerateCompanyName(Player *p)
 
 	t = ClosestTownFromTile(tile, (uint)-1);
 
-	if (IsInsideMM(t->townnametype, SPECSTR_TOWNNAME_START, SPECSTR_TOWNNAME_LAST+1)) {
+	if (t->name == NULL && IsInsideMM(t->townnametype, SPECSTR_TOWNNAME_START, SPECSTR_TOWNNAME_LAST + 1)) {
 		str = t->townnametype - SPECSTR_TOWNNAME_START + SPECSTR_PLAYERNAME_START;
 		strp = t->townnameparts;
 
