@@ -1,4 +1,4 @@
-/* $Id: string_func.h 12385 2008-03-19 20:46:56Z peter1138 $ */
+/* $Id: string_func.h 14269 2008-09-07 22:14:48Z rubidium $ */
 
 /** @file string_func.h Functions related to low-level strings. */
 
@@ -48,7 +48,7 @@ static inline bool StrEmpty(const char *s) { return s == NULL || s[0] == '\0'; }
 static inline int ttd_strnlen(const char *str, int maxlen)
 {
 	const char *t;
-	for (t = str; *t != '\0' && t - str < maxlen; t++) {}
+	for (t = str; t - str < maxlen && *t != '\0'; t++) {}
 	return t - str;
 }
 
