@@ -1,4 +1,4 @@
-/* $Id: tunnelbridge_cmd.cpp 13710 2008-07-16 16:05:52Z rubidium $ */
+/* $Id: tunnelbridge_cmd.cpp 14259 2008-09-07 11:54:00Z rubidium $ */
 
 /** @file tunnelbridge_cmd.cpp
  * This file deals with tunnels and bridges (non-gui stuff)
@@ -584,7 +584,7 @@ static CommandCost DoClearTunnel(TileIndex tile, uint32 flags)
 
 	endtile = GetOtherTunnelEnd(tile);
 
-	if (GetVehicleTunnelBridge(tile, endtile) != NULL) return CMD_ERROR;
+	if (HasVehicleOnTunnelBridge(tile, endtile)) return CMD_ERROR;
 
 	_build_tunnel_endtile = endtile;
 
@@ -641,7 +641,7 @@ static CommandCost DoClearBridge(TileIndex tile, uint32 flags)
 
 	endtile = GetOtherBridgeEnd(tile);
 
-	if (GetVehicleTunnelBridge(tile, endtile) != NULL) return CMD_ERROR;
+	if (HasVehicleOnTunnelBridge(tile, endtile)) return CMD_ERROR;
 
 	direction = GetTunnelBridgeDirection(tile);
 	delta = TileOffsByDiagDir(direction);
