@@ -1,4 +1,4 @@
-/* $Id: win32_v.cpp 12167 2008-02-17 17:00:43Z smatz $ */
+/* $Id: win32_v.cpp 14426 2008-10-01 11:48:57Z rubidium $ */
 
 #include "../stdafx.h"
 #include "../openttd.h"
@@ -101,7 +101,7 @@ static const VkMapping _vk_mapping[] = {
 	AM(VK_F1, VK_F12, WKC_F1, WKC_F12),
 
 	/* Numeric part */
-	AM(VK_NUMPAD0, VK_NUMPAD9, WKC_NUM_0, WKC_NUM_9),
+	AM(VK_NUMPAD0, VK_NUMPAD9, '0', '9'),
 	AS(VK_DIVIDE,   WKC_NUM_DIV),
 	AS(VK_MULTIPLY, WKC_NUM_MUL),
 	AS(VK_SUBTRACT, WKC_NUM_MINUS),
@@ -285,7 +285,7 @@ static bool MakeWindow(bool full_screen)
 			extern const char _openttd_revision[];
 			TCHAR Windowtitle[50];
 
-			_sntprintf(Windowtitle, sizeof(Windowtitle), _T("OpenTTD %s"), MB_TO_WIDE(_openttd_revision));
+			_sntprintf(Windowtitle, lengthof(Windowtitle), _T("OpenTTD %s"), MB_TO_WIDE(_openttd_revision));
 
 			_wnd.main_wnd = CreateWindow(_T("OTTD"), Windowtitle, style, x, y, w, h, 0, 0, GetModuleHandle(NULL), 0);
 			if (_wnd.main_wnd == NULL) error("CreateWindow failed");
@@ -463,8 +463,6 @@ static LRESULT CALLBACK WndProcGdi(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lP
 			return 0;
 
 		case WM_CHAR: {
-			/* Silently drop all non-text messages as those were handled by WM_KEYDOWN */
-			if (wParam < VK_SPACE) return 0;
 			uint scancode = GB(lParam, 16, 8);
 			uint charcode = wParam;
 
@@ -490,12 +488,13 @@ static LRESULT CALLBACK WndProcGdi(HWND hwnd, UINT msg, WPARAM wParam, LPARAM lP
 		case WM_KEYDOWN: {
 			keycode = MapWindowsKey(wParam);
 
-			/* Silently drop all text messages as those will be handled by WM_CHAR
-			 * WM_KEYDOWN only handles CTRL+ commands and special keys like VK_LEFT, etc. */
-			if (keycode == 0 || (keycode > WKC_PAUSE && GB(keycode, 13, 4) == 0)) return 0;
-
-			/* Keys handled in WM_CHAR */
-			if ((uint)(GB(keycode, 0, 12) - WKC_NUM_DIV) <= WKC_MINUS - WKC_NUM_DIV) return 0;
+			/* Silently drop all messages handled by WM_CHAR. */
+			MSG msg;
+			if (PeekMessage(&msg, NULL, 0, 0, PM_NOREMOVE)) {
+				if (msg.message == WM_CHAR && GB(lParam, 16, 8) == GB(msg.lParam, 16, 8)) {
+					return 0;
+				}
+			}
 
 			HandleKeypress(0 | (keycode << 16));
 			return 0;
