@@ -1,4 +1,4 @@
-/* $Id: win32.cpp 13708 2008-07-16 10:07:38Z rubidium $ */
+/* $Id: win32.cpp 14426 2008-10-01 11:48:57Z rubidium $ */
 
 /** @file win32.cpp Implementation of MS Windows system calls */
 
@@ -526,7 +526,7 @@ static LONG WINAPI ExceptionHandler(EXCEPTION_POINTERS *ep)
 		ep->ContextRecord->EFlags
 	);
 #else
-	output += sprintf(output, "Exception %.8X at %.8X\r\n"
+	output += sprintf(output, "Exception %.8X at %.8p\r\n"
 		"Registers:\r\n"
 		" EAX: %.8X EBX: %.8X ECX: %.8X EDX: %.8X\r\n"
 		" ESI: %.8X EDI: %.8X EBP: %.8X ESP: %.8X\r\n"
@@ -592,9 +592,9 @@ static LONG WINAPI ExceptionHandler(EXCEPTION_POINTERS *ep)
 	output = PrintModuleList(output);
 
 	{
-		OSVERSIONINFO os;
+		_OSVERSIONINFOA os;
 		os.dwOSVersionInfoSize = sizeof(os);
-		GetVersionEx(&os);
+		GetVersionExA(&os);
 		output += sprintf(output, "\r\nSystem information:\r\n"
 			" Windows version %d.%d %d %s\r\n",
 			os.dwMajorVersion, os.dwMinorVersion, os.dwBuildNumber, os.szCSDVersion);
@@ -797,7 +797,7 @@ void FiosGetDrives()
 	TCHAR drives[256];
 	const TCHAR *s;
 
-	GetLogicalDriveStrings(sizeof(drives), drives);
+	GetLogicalDriveStrings(lengthof(drives), drives);
 	for (s = drives; *s != '\0';) {
 		FiosItem *fios = FiosAlloc();
 		fios->type = FIOS_TYPE_DRIVE;
@@ -1048,14 +1048,14 @@ void DetermineBasePaths(const char *exe)
 	TCHAR path[MAX_PATH];
 #ifdef WITH_PERSONAL_DIR
 	SHGetFolderPath(NULL, CSIDL_PERSONAL, NULL, SHGFP_TYPE_CURRENT, path);
-	strncpy(tmp, WIDE_TO_MB_BUFFER(path, tmp, lengthof(tmp)), lengthof(tmp));
+	strecpy(tmp, WIDE_TO_MB_BUFFER(path, tmp, lengthof(tmp)), lastof(tmp));
 	AppendPathSeparator(tmp, MAX_PATH);
 	ttd_strlcat(tmp, PERSONAL_DIR, MAX_PATH);
 	AppendPathSeparator(tmp, MAX_PATH);
 	_searchpaths[SP_PERSONAL_DIR] = strdup(tmp);
 
 	SHGetFolderPath(NULL, CSIDL_COMMON_DOCUMENTS, NULL, SHGFP_TYPE_CURRENT, path);
-	strncpy(tmp, WIDE_TO_MB_BUFFER(path, tmp, lengthof(tmp)), lengthof(tmp));
+	strecpy(tmp, WIDE_TO_MB_BUFFER(path, tmp, lengthof(tmp)), lastof(tmp));
 	AppendPathSeparator(tmp, MAX_PATH);
 	ttd_strlcat(tmp, PERSONAL_DIR, MAX_PATH);
 	AppendPathSeparator(tmp, MAX_PATH);
@@ -1080,7 +1080,7 @@ void DetermineBasePaths(const char *exe)
 			DEBUG(misc, 0, "GetFullPathName failed (%d)\n", GetLastError());
 			_searchpaths[SP_BINARY_DIR] = NULL;
 		} else {
-			strncpy(tmp, WIDE_TO_MB_BUFFER(exec_dir, tmp, lengthof(tmp)), lengthof(tmp));
+			strecpy(tmp, WIDE_TO_MB_BUFFER(exec_dir, tmp, lengthof(tmp)), lastof(tmp));
 			char *s = strrchr(tmp, PATHSEPCHAR);
 			*(s + 1) = '\0';
 			_searchpaths[SP_BINARY_DIR] = strdup(tmp);
